==> qtcreator_4.5.2.orig.tar.xz: qt-creator-opensource-src-4.5.2/share/qtcreator/qml/qmlpuppet/commands/changebindingscommand.cpp <==
/****************************************************************************
**
** Copyright (C) 2016 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 as published by the Free Software
** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
****************************************************************************/

#include "changebindingscommand.h"

#include <QDebug>

namespace QmlDesigner {

ChangeBindingsCommand::ChangeBindingsCommand()
{
}

ChangeBindingsCommand::ChangeBindingsCommand(const QVector<PropertyBindingContainer> &bindingChangeVector)
    : m_bindingChangeVector (bindingChangeVector)
{
}

QVector<PropertyBindingContainer> ChangeBindingsCommand::bindingChanges() const
{
    return m_bindingChangeVector;
}

QDataStream &operator<<(QDataStream &out, const ChangeBindingsCommand &command)
{
    out << command.bindingChanges();

    return out;
}

QDataStream &operator>>(QDataStream &in, ChangeBindingsCommand &command)
{
    in >> command.m_bindingChangeVector;

    return in;
}

QDebug operator <<(QDebug debug, const ChangeBindingsCommand &command)
{
    return debug.nospace() << "PropertyValueContainer(bindingChanges: " << command.m_bindingChangeVector << ")";
}

} // namespace QmlDesigner

==> qtcreator_4.11.0.orig.tar.xz: qt-creator-opensource-src-4.11.0/share/qtcreator/qml/qmlpuppet/commands/changebindingscommand.cpp <==
/****************************************************************************
**
** Copyright (C) 2016 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 as published by the Free Software
** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
****************************************************************************/

#include "changebindingscommand.h"

#include <QDebug>

namespace QmlDesigner {

ChangeBindingsCommand::ChangeBindingsCommand() = default;

ChangeBindingsCommand::ChangeBindingsCommand(const QVector<PropertyBindingContainer> &bindingChangeVector)
    : m_bindingChangeVector (bindingChangeVector)
{
}

QVector<PropertyBindingContainer> ChangeBindingsCommand::bindingChanges() const
{
    return m_bindingChangeVector;
}

QDataStream &operator<<(QDataStream &out, const ChangeBindingsCommand &command)
{
    out << command.bindingChanges();

    return out;
}

QDataStream &operator>>(QDataStream &in, ChangeBindingsCommand &command)
{
    in >> command.m_bindingChangeVector;

    return in;
}

QDebug operator <<(QDebug debug, const ChangeBindingsCommand &command)
{
    return debug.nospace() << "PropertyValueContainer(bindingChanges: " << command.m_bindingChangeVector << ")";
}

} // namespace QmlDesigner
